%* Add a member (user or group) as a member of a group in the specified org, project, or analysis       *;
%*                                                                                *; 
%* @macrotype SDD                                                                 *;
%* @exposure internal                                                             *;

%macro sasdrugdev_addgroupmember(sdd_path=, sdd_group=, sdd_member=%str(), sdd_type=user, sdd_group_context=%str())
  /des='Add a member to the group in the specified context';

  /*  initialize return code and message in case macro aborts          */ 
  %global _sddRC_ _sddMsg_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  /*  start the datastep to call the java code                         */ 
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
	attrib logMsgPrefix     length=$70;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/GroupCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  attempt the operation                                        */ 
    cmd.callVoidMethod("addMember", results, "%bquote(&sdd_group)", "%bquote(&sdd_type)", "%bquote(&sdd_member)", "%bquote(&sdd_group_context)" );
    
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    
    /*  setup the logging messages                                     */ 
	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
	if (returnCode ne 0) then do;
		logMsgPrefix="ERROR: SAS Drug Development Macro:";
	end;

    /* print message in log                                            */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro addgroupmember";
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
	put logMsgPrefix " sdd_group = &sdd_group" ;
	put logMsgPrefix " sdd_type =  &sdd_type" ;
  	put logMsgPrefix " sdd_member = &sdd_member" ;
	put logMsgPrefix " sdd_group_context =  &sdd_group_context" ;
  	put;
  	
    /*  set the return code and message macro variables                */ 
	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_addgroupmember;
