%* Add a privilege to a role in the specified org, project, or analysis       *;
%*                                                                                *; 
%* @macrotype SDD                                                                 *;
%* @exposure internal                                                             *;

%macro sasdrugdev_addroleprivilege(sdd_path=, sdd_role=, sdd_privilege=%str())
  /des='Add a privilege to the role in the specified context';

  /*  initialize return code and message in case macro aborts          */ 
  %global _sddRC_ _sddMsg_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  /*  start the datastep to call the java code                         */ 
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
	attrib logMsgPrefix     length=$70;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/RoleCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  attempt the operation                                        */ 
    cmd.callVoidMethod("addPrivilege", results, "%bquote(&sdd_role)", "%bquote(&sdd_privilege)" );
    
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    
    /*  setup the logging messages                                     */ 
	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
	if (returnCode ne 0) then do;
		logMsgPrefix="ERROR: SAS Drug Development Macro:";
	end;

    /* print message in log                                            */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro addroleprivilege";
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
	put logMsgPrefix " sdd_role = &sdd_role" ;
  	put logMsgPrefix " sdd_privilege = &sdd_privilege" ;
  	put;
  	
    /*  set the return code and message macro variables                */ 
	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_addroleprivilege;
