%* Determine if a role is assign to an org, project, or analysis       *;
%*                                                                     *; 
%* @macrotype SDD                                                      *;
%* @exposure internal                                                  *;

%macro sasdrugdev_assignedroleexists(sdd_path=, sdd_role=%str(), sdd_role_context=%str())
  /des='Is the role assigned to a context';

  %global _sddRC_ _sddMsg_ _sddAssignedRoleExists_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  data _null_;
    attrib returnCode  		length=8;
    attrib foundCode  		length=8;
    attrib notFoundCode 	length=8;
    attrib message     		length=$200;

	attrib logMsgPrefix     length=$70;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/RoleCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");

    /*  perform the operation  */ 
    cmd.callVoidMethod("assignedRoleExists", results, "%bquote(&sdd_role)", "%bquote(&sdd_role_context)");
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    results.callIntMethod("getCode", "VALID_CONTEXT_ENTITY_CODE", foundCode);
    results.callIntMethod("getCode", "INVALID_CONTEXT_ENTITY_CODE", notFoundCode);

	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";

	if (returnCode = foundCode) then
    	call symputx("_sddAssignedRoleExists_", 1) ;
    else 
       	call symputx("_sddAssignedRoleExists_", 0);

	if (returnCode ne notFoundCode AND returnCode ne foundCode) then
		logMsgPrefix="ERROR: SAS Drug Development Macro:";

    /* print message in log: success or failure  */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro assignedroleexists";
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
  	put logMsgPrefix " sdd_role = &sdd_role" ;
    put logMsgPrefix " sdd_role_context = &sdd_role_context" ;
  	put;

	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_assignedroleexists ;
