%* Copy a file or folder in the workspace or repository          *;
%*                                                               *; 
%* @macrotype SDD                                                *;
%* @exposure internal                                            *;

%macro sasdrugdev_copy(sdd_source=, sdd_target=);

  /*  initialize return code and message in case macro aborts          */ 
  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);

  /*  prevent copying item to the same location                        */ 
  %if (%bquote(&sdd_source)=%bquote(&sdd_target)) %then
    %do;
        %let _sddRC_=%str(-37);
        %let _sddMsg_=%str(The target of a copy can not be the same as the source.);		
        %return;
    %end;
  
  /*  start the datastep to call the java code                         */ 
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
	attrib logMsg	        length=$300;
	attrib logMsgPrefix     length=$70;

    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/CopyCommand", "%bquote(&sdd_source)", "%bquote(&sdd_target)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  copy the object                                                */ 
    cmd.callVoidMethod("execute", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    /*  setup the logging messages                                     */ 
    if (returnCode=0) then do;
	    /* print message in log: success      */ 
		logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
		logMsg=" * The copy operation was successfully." ;
    end;
  	else do;
	  	/* error occurred              */ 
		logMsgPrefix="ERROR: SAS Drug Development Macro:";
		logMsg=" * The copy failed; target was not created." ;
    end;

    /* print message in log                                            */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro copy";
	put logMsgPrefix " " logMsg;
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_source = &sdd_source" ;
	put logMsgPrefix " sdd_target = &sdd_target" ;
  	put;

    /*  set the return code and message macro variables                */ 
	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_copy ;
