%* Create a file in the workspace or repository                  *;
%*                                                               *; 
%* @macrotype SDD                                                *;
%* @exposure internal                                            *;

%macro sasdrugdev_createfile(local_path=, sdd_path=, sdd_versioning=%str(), sdd_version=%str(), sdd_comment=%str());

  /*  initialize return code and message in case macro aborts          */ 
  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  /*  start the datastep to call the java code                         */ 
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
	attrib logMsg	        length=$300;
	attrib logMsgPrefix     length=$70;

    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/CreateFileCommand", "%bquote(&local_path)", "%bquote(&sdd_path)", "%bquote(&sdd_versioning)", "%bquote(&sdd_version)", "%bquote(&sdd_comment)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  attempt to create the file                                     */ 
    cmd.callVoidMethod("execute", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    /*  setup the logging messages                                     */ 
    if (returnCode=0) then do;
	    /* print message in log: success      */ 
		logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
		logMsg=" * The object was created: &sdd_path" ;
    end;
   	else if (returnCode=-34) then do; 
	    /* print message in log: success but versioning info ignored */ 
		logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
		logMsg=" * The object was created, versioning parameters ignored: &sdd_path" ;
	end;
  	else do;
	  	/* error occurred              */ 
		logMsgPrefix="ERROR: SAS Drug Development Macro:";
		logMsg=" * The object was not created: &sdd_path" ;
    end;

    /* print message in log                                            */
   	put;
	put logMsgPrefix " SAS Drug Development macro createfile";
	put logMsgPrefix " " logMsg;
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
  	put logMsgPrefix " local_path= &local_path" ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
  	put logMsgPrefix " sdd_versioning = &sdd_versioning" ;
	put logMsgPrefix " sdd_version =  &sdd_version" ;
	put logMsgPrefix " sdd_comment =  &sdd_comment" ;
  	put;

    /*  set the return code and message macro variables                */
	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_createfile ;
