%* Create a group within an SDD context         *;
%*                                             *; 
%* @macrotype SDD                              *;
%* @exposure internal                          *;

%macro sasdrugdev_creategroup(sdd_path=, sdd_group=, sdd_description=%str( ));

  /*  initialize return code and message in case macro aborts          */ 
  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  /*  start the datastep to call the java code                         */ 
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
	attrib logMsg	        length=$300;
	attrib logMsgPrefix     length=$70;

    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/GroupCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  attempt to create the group                                    */ 
    cmd.callVoidMethod("create", results, "%bquote(&sdd_group)", "%bquote(&sdd_description)");
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    /*  setup the logging messages                                     */
    if (returnCode=0) then do;
	    /* print message in log: success      */ 
		logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
		logMsg=" * The group &sdd_group was created in &sdd_path" ;
    end;
  	else do;
	  	/* error occurred              */ 
		logMsgPrefix="ERROR: SAS Drug Development Macro:";
		logMsg=" * The group &sdd_group could not be created in &sdd_path" ;
	end;

    /* print message in log                                            */
    put;
    put logMsgPrefix " SAS Drug Development macro creategroup";
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put logMsgPrefix " sdd_path = &sdd_path" ;
    put logMsgPrefix " sdd_group = &sdd_group" ;
    put logMsgPrefix " sdd_description = &sdd_description" ;
    put;

    /*  set the return code and message macro variables                */
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_creategroup ;
