%* Delete an object from the workspace or repository                  *;
%*                                                                    *; 
%* @macrotype SDD                                                     *;
%* @exposure internal                                                 *;

%macro sasdrugdev_deleteobject(sdd_path=)
  /des='Delete an object from the workspace or repository';

  /*  initialize return code and message in case macro aborts          */ 
  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  /*  start the datastep to call the java code                         */ 
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/DeleteObjectCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /* attempt to delete the object                                    */ 
    cmd.callVoidMethod("execute", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    
    /* print message in log: success                                   */ 
    if (returnCode=0) then do;
    	put;
    	put "NOTE: SAS Drug Development Macro: * SAS Drug Development macro deleteObject";
    	put "NOTE: SAS Drug Development Macro: * The object was deleted: &sdd_path" ;
		put "NOTE: SAS Drug Development Macro: * _sddMsg_= " message ;
    	put "NOTE: SAS Drug Development Macro: * _sddRC_= " returnCode ;
    	put;
    end; 
  	/* error occurred                                                  */ 
  	else do;
    	put;
    	put "ERROR: SAS Drug Development Macro: * SAS Drug Developmnent macro deleteObject" ;
    	put "ERROR: SAS Drug Development Macro: * The object was not deleted: &sdd_path" ;
    	put "ERROR: SAS Drug Development Macro: * _sddMsg_= " message ;
    	put "ERROR: SAS Drug Development Macro: * _sddRC_= " returnCode ;
    	put;
    end;
    
    /*  set the return code and message macro variables                */
	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_deleteobject ;
