%* Get a list of assigned members in an SDD context (org, project, analysis)   *;
%*                                                                             *;
%* @param  sdd_path Required. Path in SDD context                              *;
%* @param  sas_dsname Optional. Name of the dataset to create                  *;
%* @macrotype SDD                                                              *;
%* @exposure internal                                                          *;

%macro sasdrugdev_getassignedmembers(sdd_path=, sas_dsname=work.sddGetAssignedMembers)
  /des='Get a list of the assigned members in an SDD context';

  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  %let _sddRowCount_=0;
  
  data &sas_dsname (label="Created by sasdrugdev_getassignedmembers" keep=contextPath type principalId descriptor grpSrcCtxt);							
    attrib returnCode           length=8;
    attrib message              length=$200;
    attrib rowCount             length=8;

	attrib contextPath	        length=$2048     label="Path of SDD Context" ;
    attrib type			        length=$40      label="Principal Type";
    attrib principalId          length=$200     label="Principal Name";
    attrib descriptor           length=$200     label="Principal Description";
	attrib grpSrcCtxt           length=$2048     label="Group context source path";
  
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/MembershipCommand", "%bquote(&sdd_path)") ;
    declare javaobj results("com/sas/hls/macro/results/ContextObjectListResult");  
    
    /*  try to get the list of members in a context                    */ 
    cmd.callVoidMethod("getAssignedMembers", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    
    /* read the resulting values into a dataset                        */ 
    if (returnCode=0) then do;
      	results.callIntMethod("getObjectCount", rowCount);
      	do row=0 to rowCount - 1;
    		contextPath="&sdd_path";
        	results.callStringMethod("getObjectType", row, type);
        	results.callStringMethod("getName", row, principalId);
        	results.callStringMethod("getDescriptor", row, descriptor);
        	results.callStringMethod("getSourceContextPath", row, grpSrcCtxt);
        	output;
      	end;
     	/* put a note in the log  */  
     	put "NOTE: SAS Drug Development Macro: sasdrugdev_getassignedmembers";
     	put "NOTE: SAS Drug Development Macro: * returned a list of assigned members in %bquote(&sdd_path)";
     	if (rowCount=0) then    
      		put "NOTE: SAS Drug Development Macro: * No members were found.";
	 	else
     		put "NOTE: SAS Drug Development Macro: * " rowCount " records written to dataset &sas_dsname";
     end;
     else do;
     	put "ERROR: SAS Drug Development Macro: sasdrugdev_getassignedmembers";
      	put "ERROR: SAS Drug Development Macro: * Return Code: " returnCode;
      	put "ERROR: SAS Drug Development Macro: * Tried to list the assigned members in %bquote(&sdd_path)";
      	put "ERROR: SAS Drug Development Macro: * " message;
     end;
     call symputx("_sddRC_", returnCode);
     call symputx("_sddMsg_", message);
     call symputx("_sddRowCount_", rowCount);
  run;

  proc sort data=&sas_dsname;
  	by type principalId;
  run;
 
%mend sasdrugdev_getassignedmembers;
