%* Determine if the workspace or repository is being used             *;
%*                                                                    *; 
%* @macrotype SDD                                                     *;
%* @exposure internal                                                 *;

%macro sasdrugdev_getcontentsource()
  /des='Get content source setting of workspace or repository';
  
  /*  initialize return code and message in case macro aborts          */ 
  %global _sddRC_ _sddMsg_ _sddContentSource_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);

  /*  start the datastep to call the java code                         */ 
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
    attrib sdd_source	 	length=$40 ;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/GetContentSourceCommand");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  attempt to get the content source                              */ 
    cmd.callVoidMethod("execute", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    
    /* print message in log: success                                   */ 
    if (returnCode=0) then do;
    	cmd.callStringMethod("getContentSourceSetting", sdd_source) ;
    	call symputx("_sddContentSource_", sdd_source);
    	put;
    	put "NOTE: SAS Drug Development Macro: * SAS Drug Development Content Source is set to: " sdd_source;
		put "NOTE: SAS Drug Development Macro: * _sddMsg_= " message ;
    	put "NOTE: SAS Drug Development Macro: * _sddRC_= " returnCode ;
    	put;
    end; 
  	/* something went wrong                                            */ 
  	else do;
    	put;
    	put "ERROR: SAS Drug Development Macro: * Could not retrieve the current value of the Content Source." ;
    	put "ERROR: SAS Drug Development Macro: * _sddMsg_= " message ;
    	put "ERROR: SAS Drug Development Macro: * _sddRC_= " returnCode ;
    	put;
    end;
    
    /*  set the return code and message macro variables                */
	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_getcontentsource ;
