%* Get a list of members in group assigned to an SDD context (org, project, analysis)   *;
%*                                                                             *;
%* @macrotype SDD                                                              *;
%* @exposure internal                                                          *;

%macro sasdrugdev_getgroupmembers(sdd_path=, sdd_group=, sas_dsname=work.sddGetGroupMembers)
  /des='Get a list of the members of a group in an SDD context';

  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  %let _sddRowCount_=0;
  
  data &sas_dsname (label="Created by sasdrugdev_getgroupmembers" keep=contextPath type principalId descriptor grpSrcCtxt);							
    attrib returnCode           length=8;
    attrib message              length=$200;
    attrib rowCount             length=8;
	attrib logMsgPrefix         length=$70;

	attrib contextPath	        length=$2048     label="Path of SDD Context" ;
    attrib type			        length=$40      label="Principal Type";
    attrib principalId          length=$200     label="Principal Name";
    attrib descriptor           length=$200     label="Principal Description";
	attrib grpSrcCtxt           length=$2048     label="Group context source path";
  
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/GroupCommand", "%bquote(&sdd_path)") ;
    declare javaobj results("com/sas/hls/macro/results/ContextObjectListResult");  
    
    /*  try to get the list of members in a context                    */ 
    cmd.callVoidMethod("getMembers", results, "%bquote(&sdd_group)");
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    results.callIntMethod("getObjectCount", rowCount);
    /*  setup the logging messages                                     */ 
	logMsgPrefix="ERROR: SAS Drug Development Macro:";
    
    /* read the resulting values into a dataset                        */ 
    if (returnCode=0) then do;
		logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      	do row=0 to rowCount - 1;
    		contextPath="&sdd_path";
        	results.callStringMethod("getObjectType", row, type);
        	results.callStringMethod("getName", row, principalId);
        	results.callStringMethod("getDescriptor", row, descriptor);
        	results.callStringMethod("getSourceContextPath", row, grpSrcCtxt);
        	output;
      	end;
	end;

    /* put a note in the log  */ 
   	put;
    put logMsgPrefix "SAS Drug Development macro sasdrugdev_getgroupmembers";
	put logMsgPrefix " returning a list of members in the group in %bquote(&sdd_path)";
    if (rowCount=0) then    
      	put logMsgPrefix "No members were found.";
 	else
     	put logMsgPrefix rowCount " records written to dataset &sas_dsname";
 	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_group = &sdd_group" ;
  	put;

    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);
  run;

  proc sort data=&sas_dsname;
  	by type principalId;
  run;
 
%mend sasdrugdev_getgroupmembers;
