%* Get a list of groups in an SDD context (org, project, analysis)    *;
%*                                                                    *;
%* @param  sdd_path Required. Path in SDD context                     *;
%* @param  sas_dsname Optional. Name of the dataset to create         *;
%* @macrotype SDD                                                     *;
%* @exposure internal                                                 *;

%macro sasdrugdev_getgroups(sdd_path=, sas_dsname=work.sddGetGroups)
  /des='Get a list of groups defined in an SDD context';

  /*  initialize return code and message in case macro aborts          */ 
  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  /*  assume no records will be created                                */ 
  %let _sddRowCount_=0;
  
  /*  start the datastep to call the java code                         */ 
  data &sas_dsname (label="Created by sasdrugdev_getgroups" keep=contextPath name description);							
    attrib returnCode           length=8;
    attrib message              length=$200;
    attrib rowCount             length=8;
	attrib contextPath	        length=$2048     label="Path of SDD Context" ;
    attrib name                 length=$200     label="Group Name";
    attrib description          length=$200     label="Group Description";
  
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/GroupCommand", "%bquote(&sdd_path)") ;
    declare javaobj results("com/sas/hls/macro/results/ContextObjectListResult");  
    
    /* attemp to list the groups associated with a context             */ 
    cmd.callVoidMethod("getGroups", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    
    /* read the resulting values into a dataset                        */ 
    if (returnCode=0) then do;
      	results.callIntMethod("getObjectCount", rowCount);
      	do row=0 to rowCount - 1;
    		contextPath="&sdd_path";
        	results.callStringMethod("getName", row, name);
        	results.callStringMethod("getDescriptor", row, description);
        	output;
      	end;
     	/* put a note in the log                                         */  
     	put "NOTE: SAS Drug Development Macro: sasdrugdev_getgroups";
     	put "NOTE: SAS Drug Development Macro: * returned a list of groups in %bquote(&sdd_path)";
     	if (rowCount=0) then    
      		put "NOTE: SAS Drug Development Macro: * No groups were found.";
	 	else
     		put "NOTE: SAS Drug Development Macro: * " rowCount " records written to dataset &sas_dsname";
     end;
       /*  something went wrong                                         */      
     else do;
     	put "ERROR: SAS Drug Development Macro: sasdrugdev_getgroups";
      	put "ERROR: SAS Drug Development Macro: * Return Code: " returnCode;
      	put "ERROR: SAS Drug Development Macro: * Tried to list the groups in %bquote(&sdd_path)";
      	put "ERROR: SAS Drug Development Macro: * " message;
     end;
     
     /* set the returnCode, message, and rowCount for use by caller     */     
     call symputx("_sddRC_", returnCode);
     call symputx("_sddMsg_", message);
     call symputx("_sddRowCount_", rowCount);
  run;

  /*  sort the resulting dataset by group name                          */ 
  proc sort data=&sas_dsname;
  	by name;
  run;
 
%mend sasdrugdev_getgroups;
