%* Get the owner of an SDD object in the repository   *;
%*                                                                             *;
%* @macrotype SDD                                                              *;
%* @exposure internal                                                          *;

%macro sasdrugdev_getowner(sdd_path=, sdd_aclType=)
  /des='Get the owner of an object.';

  %global _sddRC_ _sddMsg_ _sddOwner_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  data _null_;							
    attrib returnCode           length=8;
    attrib message              length=$200;
 	attrib logMsgPrefix         length=$70;
	attrib owner    	        length=$200;
  
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/ACLCommand", "%bquote(&sdd_path)") ;
    declare javaobj results("com/sas/hls/macro/results/StringValueResult");  
    
    /*  try to get the owner of the object                    */ 
    cmd.callVoidMethod("getOwner", results, "%bquote(&sdd_aclType)") ;
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    /*  setup the logging messages                                     */ 
	logMsgPrefix="ERROR: SAS Drug Development Macro:";
    
    /* set the value                       */ 
	owner="";
    if (returnCode=0) then do;
		logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
	    results.callStringMethod("getStringValue", owner);
	end;
	call symputx("_sddOwner_", owner) ;

    /* put a note in the log  */ 
   	put;
    put logMsgPrefix "SAS Drug Development macro sasdrugdev_getowner";
	put logMsgPrefix " returning owner of %bquote(&sdd_path)";
 	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_aclType= &sdd_aclType" ;
	put logMsgPrefix " owner = " owner ;	
  	put;

    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 
%mend sasdrugdev_getowner;
