%* Get a list of properties for the SDD object                        *;
%*                                                                    *;
%* @param  sdd_path Required. Path in SDD context                     *;
%* @param  sas_dsname Optional. Name of the dataset to create         *;
%* @macrotype SDD                                                     *;
%* @exposure internal                                                 *;

%macro sasdrugdev_getproperties(sdd_path=%str(), sas_dsname=work.sddGetProperties)
  /des='Get a list of properties for a specified object';

  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  %let _sddRowCount_=0;
  
  data &sas_dsname (label="Created by sasdrugdev_getproperties" keep=name value);							
    attrib returnCode           length=8;
    attrib message              length=$200;
    attrib rowCount             length=8;

    attrib name                 length=$200     label="Attribute Name";
    attrib value                length=$200     label="Attribute Value";
  
    /* map the required java commands                                  */   
    declare javaobj cmd("com/sas/hls/macro/command/GetPropertiesCommand", "%bquote(&sdd_path)") ;
    declare javaobj results("com/sas/hls/macro/results/GetPropsResult"); 
 
    /*  try to get the properties of the selected object                    */ 
    cmd.callVoidMethod("execute", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    
    /* read the resulting values into a dataset                        */ 
    if (returnCode=0) then do;
      	results.callIntMethod("getObjectCount", rowCount);
      	do row=0 to rowCount - 1;
        	results.callStringMethod("getAttrName", row, name);
        	results.callStringMethod("getAttrValue", row, value);
        	output;
      	end;
     	/* put a note in the log                                         */  
     	put "NOTE: SAS Drug Development Macro: sasdrugdev_getproperties";
     	put "NOTE: SAS Drug Development Macro: * returned a list of properties for %bquote(&sdd_path)";
     	if (rowCount=0) then    
      		put "NOTE: SAS Drug Development Macro: * No properties were found.";
	 	else
     		put "NOTE: SAS Drug Development Macro: * " rowCount " records written to dataset &sas_dsname";
     end;
     else do;
     	put "ERROR: SAS Drug Development Macro: sasdrugdev_getproperties";
      	put "ERROR: SAS Drug Development Macro: * Return Code: " returnCode;
      	put "ERROR: SAS Drug Development Macro: * Tried to list the properties for %bquote(&sdd_path)";
      	put "ERROR: SAS Drug Development Macro: * " message;
     end;
     call symputx("_sddRC_", returnCode);
     call symputx("_sddMsg_", message);
     call symputx("_sddRowCount_", rowCount);
  run;

  proc sort data=&sas_dsname;
  	by name;
  run;
 
%mend sasdrugdev_getproperties ;
