%* Get a list of privileges in role assigned to an SDD context (org, project, analysis)   *;
%*                                                                             *;
%* @macrotype SDD                                                              *;
%* @exposure internal                                                          *;

%macro sasdrugdev_getroleprivileges(sdd_path=, sdd_role=, sas_dsname=work.sddGetRolePrivileges)
  /des='Get a list of the privileges of a role in an SDD context';

  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  %let _sddRowCount_=0;
  
  data &sas_dsname (label="Created by sasdrugdev_getroleprivileges" keep=contextPath roleName privilegeId privilegeName);							
    attrib returnCode           length=8;
    attrib message              length=$200;
    attrib rowCount             length=8;
	attrib logMsgPrefix         length=$70;

	attrib contextPath	        length=$2048     label="Path of SDD Context" ;
	attrib roleName             length=$200     label="Role name";
	attrib privilegeId          length=$200     label="Privilege Identifier";
    attrib privilegeName    	length=$200     label="Privilege Name";
  
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/RoleCommand", "%bquote(&sdd_path)") ;
    declare javaobj results("com/sas/hls/macro/results/PrivilegesListResult");  
    
    /*  try to get the list of privileges in a context                    */ 
    cmd.callVoidMethod("getPrivileges", results, "%bquote(&sdd_role)");

	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    results.callIntMethod("getObjectCount", rowCount);
    /*  setup the logging messages                                     */ 
	logMsgPrefix="ERROR: SAS Drug Development Macro:";
    
    /* read the resulting values into a dataset                        */ 
    if (returnCode=0) then do;
		logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      	do row=0 to rowCount - 1;
    		contextPath="&sdd_path";
			roleName="&sdd_role";
        	results.callStringMethod("getIdentifier", row, privilegeName);
        	results.callStringMethod("getName", row, privilegeId);
        	output;
      	end;
	end;

    /* put a note in the log  */ 
   	put;
	put logMsgPrefix "SAS Drug Development macro sasdrugdev_getroleprivileges";
	put logMsgPrefix " returning a list of privileges in the role in %bquote(&sdd_path)";
    if (rowCount=0) then    
      	put logMsgPrefix "No privileges were found.";
 	else
     	put logMsgPrefix rowCount " records written to dataset &sas_dsname";
 	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_role = &sdd_role" ;
  	put;

    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);
  run;

  proc sort data=&sas_dsname;
  	by privilegeId;
  run;
 
%mend sasdrugdev_getroleprivileges;
