%* Get a list of roles in an SDD context (org, project, analysis)     *;
%*                                                                    *;
%* @param  sdd_path Required. Path in SDD context                     *;
%* @param  sas_dsname Optional. Name of the dataset to create         *;
%* @macrotype SDD                                                     *;
%* @exposure internal                                                 *;

%macro sasdrugdev_getroles(sdd_path=, sas_dsname=work.sddGetRoles, sdd_getInherited=1)
  /des='Get a list of roles in an SDD context';

  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  %let _sddRowCount_=0;
  
  data &sas_dsname (label="Created by sasdrugdev_getroles" keep=contextPath name description roleSrcCtxt
						%if (&sdd_getInherited eq %str(1)) %then %do;
							isInherited
						%end;
					);							
    attrib returnCode           length=8;
    attrib message              length=$200;
    attrib rowCount             length=8;

    attrib contextPath	        length=$2048     label="Path of SDD Context" ;
    attrib name                 length=$200      label="Role Name";
    attrib description          length=$200      label="Role Description";
    attrib roleSrcCtxt          length=$2048     label="Role context source path";

	%if (&sdd_getInherited eq %str(1)) %then %do;
		attrib isInherited          length=$1       label="Is role inherited in current context: 0 or 1";
	%end;
  
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/RoleCommand", "%bquote(&sdd_path)") ;
    declare javaobj results("com/sas/hls/macro/results/ContextObjectListResult");  
    
    /*  try to get the roles                     */ 
    cmd.callVoidMethod("getRoles", results, "%bquote(&sdd_getInherited)") ;
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    
    /* read the resulting values into a dataset                        */ 
    if (returnCode=0) then do;
      	results.callIntMethod("getObjectCount", rowCount);
      	do row=0 to rowCount - 1;
    		contextPath="&sdd_path";
        	results.callStringMethod("getName", row, name);
        	results.callStringMethod("getDescriptor", row, description);
        	results.callStringMethod("getSourceContextPath", row, roleSrcCtxt);
			%if (&sdd_getInherited eq %str(1)) %then %do;
        		results.callStringMethod("getIsInherited", row, isInherited);
			%end;
        	output;
      	end;
     	/* put a note in the log                                         */  
     	put "NOTE: SAS Drug Development Macro: sasdrugdev_getroles";
     	put "NOTE: SAS Drug Development Macro: * returned a list of roles in %bquote(&sdd_path)";
     	put "NOTE: SAS Drug Development Macro: * sdd_getInherited = &sdd_getInherited";
     	if (rowCount=0) then    
      		put "NOTE: SAS Drug Development Macro: * No roles were found.";
	 	else
     		put "NOTE: SAS Drug Development Macro: * " rowCount " records written to dataset &sas_dsname";
     end;
     else do;
     	put "ERROR: SAS Drug Development Macro: sasdrugdev_getroles";
      	put "ERROR: SAS Drug Development Macro: * Return Code: " returnCode;
      	put "ERROR: SAS Drug Development Macro: * Tried to list the roles in %bquote(&sdd_path)";
     	put "ERROR: SAS Drug Development Macro: * sdd_getInherited = &sdd_getInherited";
      	put "ERROR: SAS Drug Development Macro: * " message;
     end;
     call symputx("_sddRC_", returnCode);
     call symputx("_sddMsg_", message);
     call symputx("_sddRowCount_", rowCount);
  run;

  proc sort data=&sas_dsname;
  	by name;
  run;
 
%mend sasdrugdev_getroles;
