%* Determine if a group exists in an org, project, or analysis       *;
%*                                                                                *; 
%* @macrotype SDD                                                                 *;
%* @exposure internal                                                             *;

%macro sasdrugdev_groupexists(sdd_path=, sdd_group=%str())
  /des='Does the group exist in the context';

  %global _sddRC_ _sddMsg_ _sddGroupExists_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  data _null_;
    attrib returnCode  		length=8;
    attrib foundCode  		length=8;
    attrib notFoundCode 	length=8;
    attrib message     		length=$200;

	attrib logMsgPrefix     length=$70;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/GroupCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");

    /*  does the group exist                                         */ 
    cmd.callVoidMethod("exists", results, "%bquote(&sdd_group)");
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    results.callIntMethod("getCode", "VALID_CONTEXT_ENTITY_CODE", foundCode);
    results.callIntMethod("getCode", "INVALID_CONTEXT_ENTITY_CODE", notFoundCode);

	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";

	if (returnCode = foundCode) then
    	call symputx("_sddGroupExists_", 1) ;
    else
       	call symputx("_sddGroupExists_", 0);

	if (returnCode ne notFoundCode AND returnCode ne foundCode) then
		logMsgPrefix="ERROR: SAS Drug Development Macro:";

    /* print message in log: success  */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro groupexists";
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
  	put logMsgPrefix " sdd_group = &sdd_group" ;
  	put;

	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_groupexists ;
