%* Determine if an object is a container       *;
%*                                             *; 
%* @macrotype SDD                              *;
%* @exposure internal                          *;

%macro sasdrugdev_iscontainer(sdd_path=)
  /des='Determine if the object is a container';

  %global _sddRC_ _sddMsg_ _sddIsContainer_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
	attrib logMsgPrefix     length=$70;
    attrib isContainerCode	length=8;
    attrib isNotContainer 	length=8;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/IsAContainerCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  is the object a container?      */ 
    cmd.callVoidMethod("execute", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
   	results.callIntMethod("getCode", "VALID_CONTAINER_CODE", isContainerCode);
    results.callIntMethod("getCode", "INVALID_CONTAINER_CODE", isNotContainer);

    if (returnCode = isContainerCode) then
    	call symputx("_sddIsContainer_", 1) ;
    else
       	call symputx("_sddIsContainer_", 0);

	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
	if (returnCode ne isContainerCode AND returnCode ne isNotContainer) then
		logMsgPrefix="ERROR: SAS Drug Development Macro:";

    /* print message in log: success  */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro iscontainer";
   	put logMsgPrefix " Testing if object is a container: &sdd_path" ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " _sddMsg_= " message ;
  	put;
	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
%mend sasdrugdev_iscontainer;
