%* Determine if a user or group is a member of an org, project, or analysis       *;
%*                                                                                *; 
%* @macrotype SDD                                                                 *;
%* @exposure internal                                                             *;

%macro sasdrugdev_ismember(sdd_path=, sdd_member=%str(), sdd_type=user, sdd_group_context=%str())
  /des='Is the user or group a member in the context';

  %global _sddRC_ _sddMsg_ _sddIsMember_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  data _null_;
    attrib returnCode  		length=8;
    attrib foundCode  		length=8;
    attrib notFoundCode 	length=8;
    attrib message     		length=$200;
	attrib logMsgPrefix     length=$70;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/MembershipCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  is the principal a member of the context                               */ 
    cmd.callVoidMethod("isMember", results, "%bquote(&sdd_type)", "%bquote(&sdd_member)", "%bquote(&sdd_group_context)");
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    results.callIntMethod("getCode", "MEMBER_FOUND_CODE", foundCode);
    results.callIntMethod("getCode", "MEMBER_NOT_FOUND_CODE", notFoundCode);

	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";

	if (returnCode = foundCode) then
    	call symputx("_sddIsMember_", 1) ;
    else
       	call symputx("_sddIsMember_", 0);

	if (returnCode ne notFoundCode AND returnCode ne foundCode) then
		logMsgPrefix="ERROR: SAS Drug Development Macro:";

    /* print message in log: success  */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro ismember";
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
  	put logMsgPrefix " sdd_member = &sdd_member" ;
	put logMsgPrefix " sdd_type = &sdd_type" ;
	put logMsgPrefix " sdd_group_context = &sdd_group_context" ;
  	put;

	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_ismember ;
