%* Determine if a role in the specified org, project, or analysis has a specific privilege    *;
%*                                                                                *; 
%* @macrotype SDD                                                                 *;
%* @exposure internal                                                             *;

%macro sasdrugdev_isroleprivilege(sdd_path=, sdd_role=, sdd_privilege=%str())
  /des='Is the privilege in the role in the specified context';

  %global _sddRC_ _sddMsg_ _sddIsRolePrivilege_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  data _null_;
    attrib returnCode  		length=8;
    attrib foundCode  		length=8;
    attrib notFoundCode 	length=8;
    attrib message     		length=$200;
	attrib logMsgPrefix     length=$70;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/RoleCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
   /*  attempt the operation                                       */ 
    cmd.callVoidMethod("hasPrivilege", results, "%bquote(&sdd_role)", "%bquote(&sdd_privilege)");

	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    results.callIntMethod("getCode", "PRIVILEGE_FOUND_CODE", foundCode);
    results.callIntMethod("getCode", "PRIVILEGE_NOT_FOUND_CODE", notFoundCode);

	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";

	if (returnCode = foundCode) then
    	call symputx("_sddIsRolePrivilege_", 1) ;
    else
       	call symputx("_sddIsRolePrivilege_", 0);

	if (returnCode ne notFoundCode AND returnCode ne foundCode) then
		logMsgPrefix="ERROR: SAS Drug Development Macro:";

    /* print message in log: success  */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro isroleprivilege";
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
	put logMsgPrefix " sdd_role = &sdd_role" ;
  	put logMsgPrefix " sdd_privilege = &sdd_privilege" ;
  	put;

	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_isroleprivilege ;
