%* Initialize connection to SDD                                       *;
%*                                                                    *;
%* @param  sdd_url Required. url to connect to                        *;
%* @param  sdd_userid Required. userid to login                       *;
%* @param  sdd_password Required. password for user <userid>          *; 
%* @param  debug Required. "ALL", "DEBUG", "INFO", "ERROR", "OFF"     *;
%* @macrotype SDD                                                     *;
%* @exposure internal                                                 *;

%macro sasdrugdev_login(sdd_url=, sdd_userid=, sdd_password=)
  /des='Initialize connection to SDD';

  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  /* are we running in SDD or from a local PC SAS session?             */
  %if %symexist(_SASDRGDEVENV_) %then ;
  %else
    %let _SASDRGDEVENV_ = PC-SAS ;
  
  data _null_;
    attrib returnCode  length=8;
    attrib message     length=$200;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/LoginCommand", "%bquote(&sdd_url)", "%bquote(&sdd_userid)", "%bquote(&sdd_password)", "%bquote(&_SASDRGDEVENV_)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  try to create a session                                        */ 
    cmd.callVoidMethod("execute", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    /* save the resulting values in macro variables                    */ 
    call symputx("_sddRC_",  returnCode);
    call symputx("_sddMsg_", message);
   run;
  
  /* success                                                           */  
  %if (&_sddRC_=0 and (&syserr ^= 0 or &syserr ^= 4)) %then
    %do;
      %let _sddMsg_ = SAS Drug Development Session initialized.;
      %put;
      %put NOTE: SAS Drug Development Macro: Input Parameters:;
      %put NOTE: SAS Drug Development Macro: * url=&sdd_url;
      %put NOTE: SAS Drug Development Macro: * sdduserid=&sdd_userid;            
      %put NOTE: SAS Drug Development Macro: * sddpassword=<Value not printed>;
	  %put NOTE: SAS Drug Development Macro: * _sddMsg_=&_sddMsg_;
      %put NOTE: SAS Drug Development Macro: * _sddRC_=&_sddRC_;
      %put;
    %end; 
  /* something went wrong during the login                             */ 
  %else
    %do;
      %put;
      %put ERROR: SAS Drug Development Macro: * Could not login to the SAS Drug Development Server.;
      %put ERROR: SAS Drug Development Macro: * Verify that your input parameters and configuration are correct.;
      %put ERROR: SAS Drug Development Macro: Input Parameters:;
      %put ERROR: SAS Drug Development Macro: * url=&sdd_url;
      %put ERROR: SAS Drug Development Macro: * sdduserid=&sdd_userid;            
      %put ERROR: SAS Drug Development Macro: * sddpassword=<Value not printed>;
      %put ERROR: SAS Drug Development Macro: * _sddMsg_=&_sddMsg_;
      %put ERROR: SAS Drug Development Macro: * _sddRC_=&_sddRC_;
      %put;
    %end;

%mend sasdrugdev_login ;
