%* Terminate connection to SDD                                       *;
%*                                                                    *; 
%* @macrotype SDD                                                     *;
%* @exposure internal                                                 *;

%macro sasdrugdev_logout()
  /des='Terminate connection to SDD';
  
  %global _sddRC_ _sddMsg_ ;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  /* are we running in SDD or from a local PC SAS session?             */
  %if %symexist(_SASDRGDEVENV_) %then ;
  %else
    %let _SASDRGDEVENV_ = PC-SAS ;
  

  data _null_;
    attrib returnCode  length=8;
    attrib message     length=$200;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/LogoutCommand" , "%bquote(&_SASDRGDEVENV_)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  try to terminate the existing session                          */ 
    cmd.callVoidMethod("execute", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    /* save the resulting values in macro variables                    */ 
    call symputx("_sddRC_",  returnCode);
    call symputx("_sddMsg_", message);
    /* print message in log: success                                   */
    if (returnCode=0) then do;
      put;
      put "NOTE: SAS Drug Development Macro: * " message;
      put;
      end;
    /* print message in log: failure                                   */
    else do;
      put;
      put "ERROR: SAS Drug Development Macro: * Unable to close connection.";
      put "ERROR: SAS Drug Development Macro: * " message;
      put;
      end;
  run;
    

    /* macro variable cleanup  */
    %if (&_sddRC_ = 0) %then %do ;
      %let loginMacVars=%str(_SDDRC_ _SDDMSG_ _sddJavaLog_   _sddDebugLevel_ _sddRunningInPE_);
    	
	  %let macName=_null_;
	  %let mvarcnt=1;

	  %do %until (&macName=%str());
	  	%let macName=%scan(&loginMacVars, &mvarcnt);
		%if (&macName ne %str()) %then %do;
		    %if (%symexist(&macName)) %then %do;
				%if (%symglobl(&macName)) %then %do;
					%put deleting global macro variable: &macName;
		    		%symdel &macName  /nowarn;
				%end;
				%else %do; 
					%put retaining local macro variable: &macName;
				%end;
			%end; * end if mac exists;
		%end; * end if macName not blank;
		%let mvarcnt=%eval(&mvarcnt+1);
	  %end; * end do until;
	%end ; * end if _sddrc_=0;
	
%mend sasdrugdev_logout ;
