%* Determine if an object exists in the workspace or repository       *;
%*                                                                    *; 
%* @macrotype SDD                                                     *;
%* @exposure internal                                                 *;

%macro sasdrugdev_objectexists(sdd_path=)
  /des='Does the object exist in the workspace or repository';

  %global _sddRC_ _sddMsg_ _sddObjectExists_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/ObjectExistsCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  does object exist                                         */ 
    cmd.callVoidMethod("execute", results);
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    if (returnCode = 1) then
    	call symputx("_sddObjectExists_", 1) ;
    else
       	call symputx("_sddObjectExists_", 0);
    /* print message in log: success                                   */ 
    if (returnCode=1 or returnCode=-4) then do;
    	put;
    	put "NOTE: SAS Drug Development Macro: * SAS Drug Development macro objectExists";
    	put "NOTE: SAS Drug Development Macro: * Testing for the existence of: &sdd_path" ;
		put "NOTE: SAS Drug Development Macro: * _sddMsg_= " message ;
    	put "NOTE: SAS Drug Development Macro: * _sddRC_= " returnCode ;
    	put;
    end; 
  	/* error occurred                                                  */ 
  	else do;
    	put;
    	put "ERROR: SAS Drug Development Macro: * SAS Drug Developmnent macro objectExists" ;
    	put "ERROR: SAS Drug Development Macro: * Testing for the existence of: &sdd_path" ;
    	put "ERROR: SAS Drug Development Macro: * _sddMsg_= " message ;
    	put "ERROR: SAS Drug Development Macro: * _sddRC_= " returnCode ;
    	put;
    end;
	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_objectexists ;
