%* Remove a member (user or group) from an org, project, or analysis       *;
%*                                                                         *; 
%* @macrotype SDD                                                          *;
%* @exposure internal                                                      *;

%macro sasdrugdev_removemember(sdd_path=, sdd_member=%str(), sdd_type=user, sdd_group_context=%str())
  /des='Remove a member from the context';

  %global _sddRC_ _sddMsg_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
	attrib logMsgPrefix     length=$70;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/context/MembershipCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  remove the member                                         */ 
    cmd.callVoidMethod("removeMember", results, "%bquote(&sdd_type)", "%bquote(&sdd_member)", "%bquote(&sdd_group_context)" );
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";

	if (returnCode ne 0) then do;
		logMsgPrefix="ERROR: SAS Drug Development Macro:";
	end;

    /* print message in log: success  */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro removemember";
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
  	put logMsgPrefix " sdd_member = &sdd_member" ;
	put logMsgPrefix " sdd_type =  &sdd_type" ;
	put logMsgPrefix " sdd_group_context =  &sdd_group_context" ;
  	put;

	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_removemember ;
