%* Remove a privilege from a role in the specified org, project, or analysis       *;
%*                                                                         *; 
%* @macrotype SDD                                                          *;
%* @exposure internal                                                      *;

%macro sasdrugdev_removeroleprivilege(sdd_path=, sdd_role=, sdd_privilege=%str())
  /des='Remove a privilege from the role in the specified context';

  %global _sddRC_ _sddMsg_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
	attrib logMsgPrefix     length=$70;
    
    /* map the required java commands                                  */  
   declare javaobj cmd("com/sas/hls/macro/command/context/RoleCommand", "%bquote(&sdd_path)");
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");
    
    /*  attempt the operation                                       */ 
    cmd.callVoidMethod("removePrivilege", results, "%bquote(&sdd_role)", "%bquote(&sdd_privilege)" );

	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

   /*  setup the logging messages                                     */ 
	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
	if (returnCode ne 0) then do;
		logMsgPrefix="ERROR: SAS Drug Development Macro:";
	end;

    /* print message in log: success  */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro removeroleprivilege";
	put logMsgPrefix " _sddMsg_= " message ;
   	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
	put logMsgPrefix " sdd_role = &sdd_role" ;
  	put logMsgPrefix " sdd_privilege = &sdd_privilege" ;
  	put;

	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_removeroleprivilege;
