%* sasdrugdev_sdd_acls_ds                                                                                                *;
%*                                                                                                                       *;
%* Validates the dataset sent in by the user to sasdrugdev_updateacls                                                    *;
%* Sets global macro variables _sddRC_ and _sddMsg_                                                                      *;
%*                                                                                                                       *;

%macro sasdrugdev_sdd_acls_ds(callingMacro=%str(sasdrugdev_updateacls), sas_dsn=%str());
	%global _sddRC_ _sddMsg_ ;
	%let _sddRC_=%str(-99);
	%let _sddMsg_=%str(The SAS Macro did not execute properly while validating the dataset &sas_dsn.  Unexpected error.);

	%put NOTE: &callingMacro.: validating dataset &sas_dsn;

	* VERIFY: dataset name;
   	%if (%qcmpres(&sas_dsn) eq %str()) %then %do;
		%let _sddMsg_= %str(Input dataset name was not provided.);
		%return;
	%end;

	%let validdsn=0;
	data _null_;
		datasetName="&sas_dsname";
		firstchar=ksubstr( kleft(datasetName),1,1);

		if ( (length(datasetName) > 32) or 
		     (anydigit(firstchar)) ) 
		then do;
			call symput("validdsn", put(1,best.));
		end;
	run;

   	%if (&validdsn eq 1) %then %do;
		%let _sddMsg_= %str(Input dataset name is not valid.);
		%return;
	%end;


	* VERIFY: dataset exists;
	%if (%sysfunc(exist(&sas_dsn))=0) %then %do;
		%let _sddMsg_= %str(Input dataset &sas_dsn does not exist. );
		%return;
	%end;

	%local dsid;
	%let DSID=%sysfunc(OPEN(&sas_dsn.,IN));

	* VERIFY: dataset has observations;
	%local nobs dsrc;
    %let RECORDS=%sysfunc(ATTRN(&DSID,NLOBS));
	%if (%eval(&RECORDS eq 0)) %then %do;
		%let _sddMsg_= %str(Input dataset &sas_dsn has no observations.);
		%let dsrc=%sysfunc(CLOSE(&DSID));
		%return;
	%end;

	* VERIFY: required parameters are present and are of type character;
	%local requiredVars;
	%let requiredVars=%str(fullpath aclType principalType principalName grpSrcCtxt adminPermission readPermission writePropPerm writeContentPerm deletePermission);

	%local varCnt varName varPos missingVars invalidVars DSINVALID;
	%let varCnt=1;
	%let varName=_null_;
	%let missingVars=%str();
	%let invalidVars=%str();
	%let DSINVALID=0;

	%do %until (&varName=%str());
		%let varName=%scan(&requiredVars, &varCnt);
		%if (&varName ne %str()) %then %do;
			%let varPos=%sysfunc(varnum(&DSID,&varName));
			%if (%eval(&varPos < 1)) %then %do;
				* required variable is missing;
				%let missingVars=%str(%trim(&missingVars) %trim(&varName));
				%let DSINVALID=1;
			%end;
			%else %if (%sysfunc(vartype(&DSID, &varPos)) ne C) %then %do;
				* required variable is not a string (character);
				%let invalidVars=%str(%trim(&invalidVars) %trim(&varName));
				%let DSINVALID=1;
			%end;
		%end; * end if varName not blank;
		%let varCnt=%eval(&varCnt+1);
	%end; * end do until;

	%let rc=%sysfunc(CLOSE(&DSID));

	%if (&DSINVALID ne 0) %then %do;
		* am only setting one message so giving missing variables precedence over variable type;
		%if (&missingVars ne %str()) %then %do;
			%let _sddMsg_= %cmpres(Dataset &sas_dsn is missing required variables: &missingVars);
			%put;
		%end;
		%else %if (&invalidVars ne %str()) %then %do;
			%let _sddMsg_= %cmpres(Variables in dataset &sas_dsn that must be character are not: &invalidVars);
		%end;
		%return;
	%end;

	%let _sddRC_=%str(0);
	%let _sddMsg_=%str(Dataset &sas_dsn is valid for sasdrugdev_updateacls.);

%mend sasdrugdev_sdd_acls_ds;
