%* Change the owner of a container or an object in SDD       *;
%*                                                                                *; 
%* @macrotype SDD                                                                 *;
%* @exposure internal                                                             *;

%macro sasdrugdev_updateowner(sdd_path=, sdd_aclType=, sdd_userid=%str())
  /des='Change the owner of an object';

  /*  initialize return code and message in case macro aborts          */ 
  %global _sddRC_ _sddMsg_;
  %let _sddRC_=%str(-99);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown error.);
  
  /*  start the datastep to call the java code                         */ 
  data _null_;
    attrib returnCode  		length=8;
    attrib message     		length=$200;
    attrib logMsgPrefix     length=$70;
    
    /* map the required java commands                                  */  
    declare javaobj cmd("com/sas/hls/macro/command/ACLCommand", "%bquote(&sdd_path)") ;
    declare javaobj results("com/sas/hls/macro/results/DefaultResult");  
    
    /*  attempt the operation                                        */ 
    cmd.callVoidMethod("updateOwner", results, "%bquote(&sdd_aclType)", "%bquote(&sdd_userid)") ;
    
	/* did it work                                                     */ 
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    
    /*  setup the logging messages                                     */ 
	logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
	if (returnCode ne 0) then do;
		logMsgPrefix="ERROR: SAS Drug Development Macro:";
	end;

    /* print message in log                                            */ 
   	put;
	put logMsgPrefix " SAS Drug Development macro sasdrugdev_updateowner";
	put logMsgPrefix " _sddMsg_= " message ;
  	put logMsgPrefix " _sddRC_= " returnCode ;
	put logMsgPrefix " sdd_path = &sdd_path" ;
	put logMsgPrefix " sdd_userid = &sdd_userid" ;
	put logMsgPrefix " sdd_aclType= &sdd_aclType" ;
  	put;
  	
    /*  set the return code and message macro variables                */ 
	call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
  run;
 	
%mend sasdrugdev_updateowner;
